!function (app) {
	var wms_url = 'http://194.42.21.85/ncWMS/wms';
	var stop_animation = null;
	var ajax_cache = {};
	var layers_mapping = {
		'CURRENTS/sea_water_velocity/0' : {
			internal_key: 'CURRENTS/sea_water_velocity/0',
			display_name : 'Current speed and direction',
			units: 'm/s',
			ncwms_layer :  [
					{name:'CURRENTS/sea_water_velocity'},
					{name:'CURRENTS/sea_water_velocity', params: {styles: 'linevec/rainbow', colorscalerange: '1,1'}},
				],
		},
		'CURRENTS/sea_water_velocity/5' : {
			internal_key: 'CURRENTS/sea_water_velocity/5',
			display_name : 'Current speed and direction at -5 m',
			units: 'm/s',
			ncwms_layer :  [
					{name:'CURRENTS/sea_water_velocity', params: {elevation: 5}},
					{name:'CURRENTS/sea_water_velocity', params: {elevation: 5, styles: 'linevec/rainbow', colorscalerange: '1,1'}},
				]
		},
		'CURRENTS/sea_water_velocity/30' : {
			internal_key: 'CURRENTS/sea_water_velocity/30',
			display_name : 'Current speed and direction at -30 m',
			units: 'm/s',
			ncwms_layer :  [
					{name:'CURRENTS/sea_water_velocity', params: {elevation: 30, styles: 'boxfill/rainbow'}},
					{name:'CURRENTS/sea_water_velocity', params: {elevation: 30, styles: 'linevec/rainbow', colorscalerange: '1,1'}},
				]
		},
		'WAVES/SWE_H' : {
			internal_key: 'WAVES/SWE_H',
			display_name : 'Swell wave height and direction',
			units: 'm',
			ncwms_layer :  [
				{name:'WAVES/SWE_H'},
				{name:'WAVES/swell_waves', params:{styles: 'linevec/rainbow', colorscalerange: '1,1'}},
			//	{name:'WAVES/waves', params:{styles: 'linevec/rainbow', colorscalerange: '1,1'}},
				],
		},
		'WAVES/waves' : {
			internal_key: 'WAVES/waves',
			display_name : 'Significant wave height and direction',
			units: 'm',
			ncwms_layer :  [
				{name:'WAVES/waves'},
				{name:'WAVES/waves', params:{styles: 'linevec/greyscale', colorscalerange: '1,1'}},
				],
		},
		'WAVES/MP' : {
			internal_key: 'WAVES/MP',
			display_name : 'Mean waves period',
			units: 'sec',
			ncwms_layer :  [
				{name:'WAVES/MP'},
				{name:'WAVES/MP', params:{styles: 'linevec/greyscale', colorscalerange: '1,1'}},
			],
		},
		'CURRENTS/TEMP/0' : {
			internal_key: 'CURRENTS/TEMP/0',
			display_name : 'Sea water temperature',
			units: '&deg;C',
			ncwms_layer :  [
				{name:'CURRENTS/TEMP', params: {elevation: 0}}
			],
		},
		'CURRENTS/TEMP/5' : {
			internal_key: 'CURRENTS/TEMP/5',
			display_name : 'Sea water temperature at -5 m',
			units: '&deg;C',
			ncwms_layer :  [
				{name:'CURRENTS/TEMP', params: {elevation: 5}}
			],
		},
		'CURRENTS/TEMP/30' : {
			internal_key: 'CURRENTS/TEMP/30',
			display_name : 'Sea water temperature at -30 m',
			units: '&deg;C',
			ncwms_layer :  [
				{name:'CURRENTS/TEMP', params: {elevation: 30}}
			],
		},
		'CURRENTS/SAL/0' : {
			internal_key: 'CURRENTS/SAL/0',
			display_name : 'Salinity',
			units: 'psu',
			ncwms_layer :  [
				{name:'CURRENTS/SAL', params: {elevation: 0}}
			],
		},
		'CURRENTS/SAL/5' : {
			internal_key: 'CURRENTS/SAL/5',
			display_name : 'Salinity at -5 m',
			units: 'psu',
			ncwms_layer :  [
				{name:'CURRENTS/SAL', params: {elevation: 5}}
			],
		},
		'CURRENTS/SAL/30' : {
			internal_key: 'CURRENTS/SAL/30',
			display_name : 'Salinity at -30 m',
			units: 'psu',
			ncwms_layer :  [
				{name:'CURRENTS/SAL', params: {elevation: 30}}
			],
		},

		'WINDS/wind' : {
			internal_key: 'WINDS/wind',
			display_name : 'Wind speed and direction',
			units: 'm/s',
			ncwms_layer :  [
				{name:'WINDS/wind'},
				{name:'WINDS/wind', params:{styles: 'linevec/greyscale', colorscalerange: '1,1'}},
			],
		},
		/*
		'WINDS/TAIR' : {
			internal_key: 'WINDS/TAIR',
			display_name : 'Air temperature',
			ncwms_layer :  [
				{name:'WINDS/TAIR'}
			],
		},
		'WINDS/RH' : {
			internal_key: 'WINDS/RH',
			display_name : 'Relative humidity',
			ncwms_layer :  [
				{name:'WINDS/RH'}
			],
		},
		'WINDS/CLOUDS' : {
			internal_key: 'WINDS/CLOUDS',
			display_name : 'Cloud fraction',
			ncwms_layer :  [
				{name:'WINDS/CLOUDS'}
			],
		},
		'WINDS/PRES' : {
			internal_key: 'WINDS/PRES',
			display_name : 'Air pressure',
			ncwms_layer :  [
				{name:'WINDS/PRES'}
			],
		},
		'WINDS/PRCP' : {
			internal_key: 'WINDS/PRCP',
			display_name : 'Precipitation',
			ncwms_layer :  [
				{name:'WINDS/PRCP'}
			],
		},
*/
	};

	app.content.marine_map = function () {
		var proxy  = is_cordova() ? '' : 'maris_proxy.php?url=';
		var active_layers = [];

		app.content_header({header:beach_title(), sidebar:true, sidebar_items: []});

		/*
		sidebar_items: [
					{target:'', 	label:'OpenStreetMap',  	class:'activate_base', data: {m_key: 'osm'}},
					{target:'',		label:'Bing', 				class:'activate_base', data: {m_key: 'bing'}},
					{target:'',		label:'Bing satellite', 	class:'activate_base', data: {m_key: 'bing_sat'}},
					{target:'', 	label:'Bing with Labels', 	class:'activate_base', data: {m_key: 'bing_labels'}}
		]

		*/

		app.content_footer();
		//app.side_menu();
		var legend_container = $('<div>',{id: 'marine_map_legend_container'});
		var legend_h2 = $('<h2>', {text: 'Legend'}).appendTo(legend_container);
		var legend_holder =  $('<div>',{id: 'marine_map_legend_holder'}).appendTo(legend_container);


		$('#side_menu_list').after(legend_container);

		var parameter_options = [];

		$.each(layers_mapping, function (i, item) {
			parameter_options.push({value: i, title:item.display_name});

		});



		function keys_to_upper (obj) {
			var output = {};
			$.each(obj, function (k, v) {
				output[k.toUpperCase()] = v;
			});
			return output;
		}

		function hours_to_ms(hours) {
			return hours * 3600 * 1000;
		}

		function get_timerange(_hours) {
			var hours		= _hours || 60,
				date 		= new Date(),
				date_string = date.toISOString().split('T')[0],
				start 		= new Date(new Date(date_string).getTime() + hours_to_ms(utc_diff)),
				end			= new Date(start.getTime() + hours_to_ms(hours));

			var times = [];

			for (var i = 0; i < hours + 1; i++) {
				times.push(new Date(start.getTime() + hours_to_ms(i)));
			}

			return times;
		}

		function format_dates_select (times) {
			var select_data = [];
			var dates = {};

			$.each(times, function (_, time) {
				var date = time.toISOString().split('T')[0];
				if (!dates[date]) {
					select_data.push({
						title: date,
						value: date
					});
					dates[date] = true;
				}

			});

			return select_data;
		}

		function format_time_select (times, filter_date) {
			var select_data = [];
			var dates = {};

			$.each(times, function (_, time) {
				if (filter_date && time.toISOString().indexOf(filter_date) !== 0) {
					return;
				}

				var date = time.toISOString().split('T')[1].replace('.000Z', '');

				if (!dates[date]) {
					select_data.push({
						title: date,
						value: time.toISOString()
					});
					dates[date] = true;
				}

			});

			return select_data;
		}



		function load_layer (layers_arr, extra_params, cb) {
// Remove current layers
			var old_active = null;

			if (active_layers.length) {
				old_active = active_layers.slice();
			}

			active_layers = [];


// Add new layers
			var base_count = layers.count('is_base') + (old_active && old_active.length ? old_active.length : 0);
			var loading_events = [];

			$.each(layers_arr.ncwms_layer, function (i, layer) {
				loading_events[i] = $.Deferred();

				var default_styles = {styles: 'boxfill/rainbow'};

				var params = keys_to_upper($.extend({ LAYERS: layer.name }, default_styles , extra_params || {}, layer.params || {}));

// Using tile layer for development, Production needs to be ImageWMS

				var new_layer =  new ol.layer.Image({title: layers_arr.internal_key + '_' + i + (new Date()).getTime(), visible: true, opacity: 1, source: new ol.source.ImageWMS({url: proxy +wms_url + '?', ratio: 1, params: params})});
				active_layers.push(new_layer);

				var osm_nosea = layers.find_m_key('osm_nosea');
				//layers.insert_at( base_count + i + 1 , new_layer);

				new_layer.getSource().once(['imageloadend', 'imageloaderror'], function (e) {												// Done or Error doesnt matter let me know
						loading_events[i].resolve();
				});

				layers.insert_at( osm_nosea , new_layer);

			});

			$.when.apply(null, loading_events.map(function (d){return d.promise();})).then(function () {										// All active layers loaded for current frame? Start countdown to next frame!
					if (old_active) {
						$.each(old_active, function (i, layer) {
							layers.remove_layer(layers.l.indexOf(layer));
						});
					}

					call(cb);
			});

		}

		$('#parameter_combo').html(fill_select(parameter_options)).selectmenu('refresh');

		$('#date_combo').on('change', function () {
			var range = get_timerange(60);
			var date = $('#date_combo').val();
			$('#time_combo')
				.html(fill_select(format_time_select(range, date)))
				.selectmenu('refresh');
		});

		 get_bbox = function () {
			//var extent = map.getView().calculateExtent( map.getSize());
			//return ol.proj.transformExtent(extent, 'EPSG:3857', 'EPSG:4326').join(',')
			//return [32.130, 34.497, 34.772, 35.751].join(',');
			return [30.927, 33.696, 35.722, 36.518].join(',');
		}

		get_legend = function(layersettings, extra){
			   var image = $('<img>', {src:proxy + wms_url + '?REQUEST=GetLegendGraphic&LAYER='+layersettings.ncwms_layer[0].name+'&PALETTE=rainbow&COLORSCALERANGE=' + (extra.colorscalerange)});
				image.img_load(function () {
					legend_holder.html(image);
				});

		};
		function back_to_utc(time_val) {
			return new Date(new Date(time_val).getTime() - hours_to_ms(utc_diff)).toISOString();
		}
		function load_map (event, buffer) {
			if (!event.animator) {
				stop_animation();
			}

			// Get current 'Parameter'
			var current_parameter = $('#parameter_combo').val();
			// Load layer
			var layer_settings = layers_mapping[current_parameter];

			var time_val = $('#time_combo').val();
			var scale_range_promise = null;
			var scale_range_url = proxy + wms_url + '?item=layerDetails&layerName='+layer_settings['ncwms_layer'][0].name+'&bbox='+get_bbox()+'&SRS=EPSG%3A4326&width=500&height=500&version=1.1.1&request=GetMetadata' + (layer_settings['ncwms_layer'][0].params && layer_settings['ncwms_layer'][0].params.elevation != undefined ? '&elevation='+ layer_settings['ncwms_layer'][0].params.elevation:'');
			if  (ajax_cache[scale_range_url]) {
				scale_range_promise = $.Deferred();
				scale_range_promise.resolve(ajax_cache[scale_range_url]);
			} else {
				//$.getJSON(proxy + wms_url + '?item=minmax&layers='+layer_settings['ncwms_layer'][0].name+'&bbox='+get_bbox()+'&time='+back_to_utc(time_val)+'&SRS=EPSG%3A4326&width=500&height=500&version=1.1.1&request=GetMetadata' + (layer_settings['ncwms_layer'][0].params && layer_settings['ncwms_layer'][0].params.elevation != undefined ? '&elevation='+ layer_settings['ncwms_layer'][0].params.elevation:''))
			 	scale_range_promise = $.getJSON(scale_range_url);
			}
			scale_range_promise.done(function (result) {
					if (!ajax_cache[scale_range_url]) {
						ajax_cache[scale_range_url] = result;
					}
					// Update other dropdowns
					var colorscalerange = result.scaleRange;
					var extra_params = {
						TIME : back_to_utc(time_val),
						//colorscalerange: result.min + ',' + result.max
						colorscalerange: (colorscalerange[0] * 0.75) + ',' + (colorscalerange[1] * 1.25)
					};

					$('#info_at_resp').html('Choose a geographical point by clicking on map');

					load_layer(layer_settings, extra_params, function () {
							if (event.loading_events) {
								$.each(event.loading_events, function (_, el) {
									el.resolve();
								});
							}
					});

					get_legend(layers_mapping[current_parameter], extra_params);

			});
		}

		$('#view_btn').on('click',load_map);

		var animation_playing =  false;
		var call_next = null;


		  stop_animation = function () {

			if (animation_playing || call_next) {
				if (call_next !== null) {
					clearTimeout(call_next);
				}

				animation_playing = false;
				call_next = null;
				return true;
			}
			return false;
		}
		//Load Layer onto map....... OR on to a similar
		function buffer_frames () {

		}

		$('#tmp_play').on('click', function () {

			if (stop_animation()) {
				return;
			}

			animation_playing = true;
			var range = get_timerange(60);																											// Get the next X hours as date objects
			var frames = range.slice();																											    // Copy all dates
			var frame_delay = 1000;																													// Play speed
			var next_scheduled_frame = null;

			var pos = frames.map(Number).indexOf(+(new Date($('#time_combo').val())));																// First frame
			frames = frames.slice(pos);

			var move_next = function () {																											// Drawing function

				if (animation_playing === false) {																											// If not playing exit function
					return;
				}

				if (!frames.length) {																												// If list is empty repopulate (circular loop)
						 frames = range.slice();
				}
				var current_frame  = frames.shift();

				if (frames.length > 2) {
					current_frame  = frames.shift();
					current_frame  = frames.shift();
				}
																											// Get frame


				$('#date_combo').val(current_frame.toISOString().split('T')[0]).selectmenu('refresh');												// Select current time
				$('#time_combo').html(fill_select(format_time_select(range, $('#date_combo').val()))).val(current_frame.toISOString()).selectmenu('refresh'); // Select current date

				var loading_events = [];																											// Holds the promises
				$.each(active_layers, function (i, active_layer) {
				//	active_layer.getSource().updateParams({
				//		TIME: current_frame.toISOString()
				//	});

					loading_events[i] = $.Deferred();
				/*
					active_layer.getSource().once(['imageloadend', 'imageloaderror'], function (e) {												// Done or Error doesnt matter let me know

						loading_events[i].resolve();
					});
				*/


				});


				load_map({animator:true, loading_events: loading_events});
				next_scheduled_frame = Date.now() + frame_delay;

				$.when.apply(null, loading_events.map(function (d){return d.promise();})).then(function () {										// All active layers loaded for current frame? Start countdown to next frame!
					if (animation_playing) {
						if (next_scheduled_frame <= Date.now()) {
							move_next();
						} else {
							call_next = setTimeout(move_next, next_scheduled_frame - Date.now());
						}

					}

				});

			};

			move_next();																															// Initial move_next()!

		});


		var info_at = function (coords, cb) {
			var result = null;
			if (!active_layers.length) {
					return result;
			}

			var layerQuery = active_layers[0];

			if (layerQuery.getVisible()) {
				var coordinate = coords;
				var view = this.map.getView();
				var viewResolution = (view.getResolution());
				var url = layerQuery.getSource().getGetFeatureInfoUrl(
					coordinate, viewResolution, view.getProjection(), {
						'INFO_FORMAT': 'text/xml'
					}
				);

				if (url) {
					$.get(url, function (data) {
						var xml_doc = $(data).find('FeatureInfoResponse');
						if (!xml_doc.length) {
							xml_doc = $($.parseXML(data)).find('FeatureInfoResponse');
						}
						call(cb, xml_doc);
					});
				}
			}

			return result;
		};
	/*
		 get_legend = function () {
			var width = $('#marine_map_legend_holder').width();
			var proxy  = is_cordova() ? '' : 'maris_proxy.php?url=';
			var $canvas = $('<canvas width="'+width+'" height="'+height+'">', {id: 'legend_canvas'});

			$('#marine_map_legend_holder').css({
				'overflow':'hidden'
			});

			$('#marine_map_legend_holder').html($canvas);

			var context = $canvas[0].getContext('2d');

			var image = $('<img>', {on:{load:function () {
				context.clearRect(0,0, width, height);
				context.translate(0,height);
				context.rotate(-(Math.PI/2));
				context.drawImage(this, 0, 0);

			}}, src:proxy + wms_url + '?REQUEST=GetLegendGraphic&COLORBARONLY=true&WIDTH='+height+'&HEIGHT='+width+'&PALETTE=rainbow&NUMCOLORBANDS=254'})[0];
		};
*/




		$(document).one('pagecontainertransition', function () {
			window.load_layers_applic = function () {
				//layers.l [layers.l.length] = new ol.layer.Image({title: "CURRENTS/sea_water_velocity/0", visible: true, opacity: 0.9, source: new ol.source.ImageWMS({url: 'maris_proxy.php?url=http://194.42.21.85/ncWMS/wms?', ratio: 1, params: { LAYERS: 'WAVES/waves', serverType: 'linda_gis' }})});
			};

			function set_map_height() {

				var map_height = 0;

				if ($.is_landscape()) {
					$('.map_scroll_btn a').show();
					map_height = $(window).height() - ($('#marine_map .ui-header').height() + $('#marine_map .ui-footer').height() );
					$('#map_div_marine_map').height(map_height);
				} else {
					$('.map_scroll_btn a').hide();
					//5px extra uitloop ergens??
					 map_height = $(window).height()  - ($('#marine_map_ui').outerHeight() + 5 + $('#marine_map .ui-header').outerHeight() + $('#marine_map .ui-footer').outerHeight());
					$('#map_div_marine_map').height(map_height);
				}



			}

			identify = false;
			map_init('map_div_marine_map', function () {
				set_map_height();
				map.updateSize();
				setTimeout(function () {
					if ($.is_landscape()) {
						$('.map_scroll_btn a').show();
					} else {
						$('.map_scroll_btn a').hide();
					}
				},200);
			});

			set_map_height();

			//get_legend();

			map.on('change:size', set_map_height);

			var osm_index = layers.find_m_key('osm');
			var osm_layer = layers.l[osm_index];

			var layer = new ol.layer.Tile({title: "OSM No Sea",visible: true, m_key: 'osm_nosea',extent: new ol.proj.transformExtent([32.130, 34.497, 34.772, 35.751], 'EPSG:4326', 'EPSG:3857'),source: new ol.source.XYZ({url:proxy +'http://geoservice.maris2.nl/tiles/osm/osmnosea-bright/{z}/{x}/{y}.png'})});
			var layer_admin = new ol.layer.Tile({title: "OSM Admin",visible: true, is_base_static:true, extent: new ol.proj.transformExtent([32.130, 34.497, 34.772, 35.751],'EPSG:4326', 'EPSG:3857'), source: new ol.source.XYZ({url:proxy +'http://geoservice.maris2.nl/tiles/osm/osm-noadmin/{z}/{x}/{y}.png'})});
			//var cyprusClipGeom = [[3587648.4091649936,4195150.79286976],[3612796.1500521386,4184351.6673256126],[3629306.500329143,4198415.993562531],[3654225.0343847447,4198263.179845799],[3665384.813336771,4224098.841902513],[3694583.8044523555,4218901.130963953],[3755198.3803842016,4224359.276993561],[3849521.6113231573,4275770.356756705],[3863891.73307017,4254826.595257874],[3793722.6052435385,4190726.9457133496],[3809927.272198824,4149343.518793351],[3774001.8008520557,4144298.638846041],[3711782.1091824616,4115864.0193546987],[3678149.8193460354,4099965.1718153334],[3660875.038125754,4101493.9074979816],[3606757.624274058,4124272.1402285183],[3587648.4091649936,4152095.147747826],[3584132.2717287964,4183281.468433536]];
			var cyprusClipGeom = [[3655524.440710269,4255402.238692334],[3876274.578397858,4307379.417926253],[3912964.351974743,4215043.487757758],[3802283.5350178075,4115369.6028738893],[3647574.9897686113,4070730.378355347],[3556462.052052681,4103139.678348262],[3546066.6162058967,4166123.7896552463],[3598043.7954398156,4230330.893414794],[3655524.440710269,4255402.238692334]];
			var borderClip = [[3935003.26381727,3733479.5093784155],[3974815.751228053,3865108.4355571303],[4017415.8336462565,4132158.6653185086],[3951945.249857305,4174669.142917614],[3799839.79849504,3973240.2652192744],[3839236.451555309,3768775.924538188],[3935003.26381727,3733479.5093784155]];

			var polygon = new ol.geom.Polygon([cyprusClipGeom]);
			var polygon_border = new ol.geom.Polygon([cyprusClipGeom]);

			layers.insert_at(osm_index + 1, layer_admin);
			layers.add_layer(layer);

			layers.clip(layer, polygon);
			layers.clip(layer_admin, polygon_border, {
				color: 'rgba(181, 208, 208, 1)',
				mask: true
			});

			layer_admin.bindTo('visible', osm_layer, 'visible');
			layer.bindTo('visible', osm_layer, 'visible');





			$(document).one('pagecontainerbeforechange', function (e){
				stop_animation();
			});


			map.on('singleclick', function (e) {
				var coordinates = e.coordinate;
				info_at(coordinates, function (result) {
					var res = result.find('value').text();
					var l = layers_mapping[$('#parameter_combo').val()];
					res = res.trim() == 'none' ? 'none' : res.trim() + ' '+ l.units;
					$('#info_at_resp').html(res);
				});


			});

			//layer.bindTo('visible', layers.l[layers.find_m_key('osm')] , 'visible');

			var current_base = layers.l.filter(function (l) { return l.get('is_base') && l.get('visible');})[0];




			$('.activate_base').each(function () {
				var l = $(this);
				if (l.data('m_key') == current_base.get('m_key')) {
					l.addClass('active-base');
				}
			});

			$('.activate_base').on('tap', function () {
				var item = $(this);
				var m_key = item.data('m_key');
				var base_layers = layers.l.filter(function (l) { return l.get('is_base');});
				$('.activate_base').removeClass('active-base');
				item.addClass('active-base');

				$.each(base_layers, function (_, layer) {
					if (layer.get('m_key') == m_key) {
						layer.setVisible(true);
					} else {
						layer.setVisible(false);
					}
				});
			});

			$('#parameter_combo').change(function(){
					stop_animation();
			});

			var scroll_up_btn = function () {
				var this_ = this;
				var scroll_div = $('<div>', {
					class: 'map_scroll_btn ol-unselectable',
				});

				var scroll_icon = $('<a>').appendTo(scroll_div);

				scroll_div.on('click touchend', function (e) {
					e.preventDefault();
					$.mobile.silentScroll(0);
				});

				ol.control.Control.call(this_, {
					element: scroll_div[0],
					target: ''
				});

			};

			ol.inherits(scroll_up_btn, ol.control.Control);


			map.addControl(new scroll_up_btn());

			if (params.region && params.beach) {
				get_json('get_beach/'+params.region+'/'+params.beach, function (result) {
					var beach = result.Beach;
					var view = map.getView();
//					var coords = new ol.proj.transform([Number(beach.Latitude),Number(beach.Longitude)], 'EPSG:4326', 'EPSG:3857');
// aanpassing json lat = lon en lon = lat, zie emails.
					var coords = new ol.proj.transform([Number(beach.Longitude),Number(beach.Latitude)], 'EPSG:4326', 'EPSG:3857');
					view.setCenter(coords);
					view.setResolution(150);

					var range = get_timerange();

					$('#date_combo').html(fill_select(format_dates_select(range)));
					$('#time_combo')
						.html(fill_select(format_time_select(range, $('#date_combo').val())));

					$('#date_combo, #time_combo').selectmenu('refresh');

					$('#view_btn').click();


					get_json('geo_json_beach', function (result) {
						var beaches = result;
						var current_beach = result.features.filter(function (feature) {return feature.properties.beach == params.beach;})[0];
						var coords = new ol.proj.transform(current_beach.geometry.coordinates, 'EPSG:4326', 'EPSG:3857');

						beach_source = new ol.source.Vector({
							features: [
								new ol.Feature({
									geometry: new ol.geom.Point(coords),
								})
							]
						});

						var style = [new ol.style.Style({
							image: new ol.style.Icon(({
								anchor: [13, 37],
								anchorXUnits: 'pixels',
								anchorYUnits: 'pixels',
								src: 'grfx/map_icon.png'
							}))
						})];

						beach_layer = new ol.layer.Vector({
							source: beach_source,
							style: style
						});

						layers.add_layer(beach_layer);


					});





				});
			}

		});
	};



}(m_application);
